Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(146)

Unified Diff: src/dateparser.h

Issue 1409343005: Version 4.6.85.28 (cherry-pick) (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@4.6
Patch Set: Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « include/v8-version.h ('k') | src/dateparser-inl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/dateparser.h
diff --git a/src/dateparser.h b/src/dateparser.h
index a9db8685d90466d887544557cefdf1c14b8a32d5..aa57bb1c667f8e58d11205d4c4b35f8cef7f09c1 100644
--- a/src/dateparser.h
+++ b/src/dateparser.h
@@ -368,13 +368,13 @@ class DateParser : public AllStatic {
bool is_iso_date_;
};
// Tries to parse an ES6 Date Time String. Returns the next token
// to continue with in the legacy date string parser. If parsing is
// complete, returns DateToken::EndOfInput(). If terminally unsuccessful,
// returns DateToken::Invalid(). Otherwise parsing continues in the
// legacy parser.
template <typename Char>
- static DateParser::DateToken ParseES6DateTime(
+ static DateParser::DateToken ParseES5DateTime(
DateStringTokenizer<Char>* scanner,
DayComposer* day,
TimeComposer* time,
@@ -368,13 +368,13 @@ class DateParser : public AllStatic {
bool is_iso_date_;
};
- // Tries to parse an ES6 Date Time String. Returns the next token
+ // Tries to parse an ES5 Date Time String. Returns the next token
// to continue with in the legacy date string parser. If parsing is
// complete, returns DateToken::EndOfInput(). If terminally unsuccessful,
« no previous file with comments | « include/v8-version.h ('k') | src/dateparser-inl.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698